#!/usr/bin/ruby -Ks

require 'test/unit'

require 'bencoding'

include Btrb::Bencoding

class TestBencoding < Test::Unit::TestCase
  def setup
  end

  def teardown
  end

  def test_nil()
    r = decode('')
    assert_equal(0, r.size)
  end

  def test_string()
    r = decode('1:A')
    assert_equal(1, r.size)
    assert_equal('A', r[0])
    r = decode('1:A4:1234')
    assert_equal(2, r.size)
    assert_equal('A', r[0])
    assert_equal('1234', r[1])
    r = decode('0:2:AB')
    assert_equal(2, r.size)
    assert_equal('', r[0])
    assert_equal('AB', r[1])
  end

  def test_list()
    r = decode('l4:spam4:eggse')
    assert_equal(1, r.size)
    assert_instance_of(Array, r[0])
    assert_equal('spam', r[0][0])
    assert_equal('eggs', r[0][1])
    r = decode('l4:spamd3:cow3:mooee')
    assert_equal('spam', r[0][0])
    assert_equal('moo', r[0][1]['cow'])
  end

  def test_integer()
    r = decode('i32e')
    assert_equal(1, r.size)
    assert_equal(32, r[0])
    r = decode('i-32ei111111111111e')
    assert_equal(2, r.size)
    assert_equal(-32, r[0])
    assert_equal(111111111111, r[1])
  end

  def test_dictionary()
    r = decode('d3:cow3:moo4:spam4:eggs4:1234i32ee')
    assert_equal(1, r.size)
    assert_instance_of(Hash, r[0])
    assert_equal('moo', r[0]['cow'])
    assert_equal('eggs', r[0]['spam'])
    assert_equal(32, r[0]['1234'])
    r = decode('d4:spaml1:a1:bee')
    assert_equal('a', r[0]['spam'][0])
    assert_equal('b', r[0]['spam'][1])
    r = decode('d4:spamd3:cow3:mooee')
    assert_equal('moo', r[0]['spam']['cow'])
  end
end

